========
pipettor
========

Robust, easy to use Python package for running Unix process pipelines

Contents:
=========

.. toctree::
   :titlesonly:
   :maxdepth: 1

   readme
   installation
   usage
   library
   contributing
   authors
   history
   modules
   design

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

